==> estateplat-common-1.1.0-20160804.135445-140-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLsCfBh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/7/31
 * @description 不动产查封历史变化关系
 */
@Table(name = "BDC_LS_CF_BH")
public class BdcLsCfBh implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 查封Id
     */
    private String cfid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原查封Id
     */
    private String ycfid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 查封文号
     */
    private String cfwh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原查封文号
     */
    private String ycfwh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原权利人
     */
    private String yqlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原权利人证件号
     */
    private String yqlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原坐落
     */
    private String yzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登簿时间
     */
    private Date bdsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 不动产类型
     */
    private String bdclx;

    public String getCfid() {
        return cfid;
    }

    public void setCfid(String cfid) {
        this.cfid = cfid;
    }

    public String getYcfid() {
        return ycfid;
    }

    public void setYcfid(String ycfid) {
        this.ycfid = ycfid;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYcfwh() {
        return ycfwh;
    }

    public void setYcfwh(String ycfwh) {
        this.ycfwh = ycfwh;
    }

    public String getYqlr() {
        return yqlr;
    }

    public void setYqlr(String yqlr) {
        this.yqlr = yqlr;
    }

    public String getYqlrzjh() {
        return yqlrzjh;
    }

    public void setYqlrzjh(String yqlrzjh) {
        this.yqlrzjh = yqlrzjh;
    }

    public String getYzl() {
        return yzl;
    }

    public void setYzl(String yzl) {
        this.yzl = yzl;
    }

    public Date getBdsj() {
        return bdsj;
    }

    public void setBdsj(Date bdsj) {
        this.bdsj = bdsj;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }
}

==> estateplat-common-1.1.0-20160926.064453-195-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLsCfBh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/7/31
 * @description 不动产查封历史变化关系
 */
@Table(name = "BDC_LS_CF_BH")
public class BdcLsCfBh implements Serializable{
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 查封Id
     */
    private String cfid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原查封Id
     */
    private String ycfid;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 查封文号
     */
    private String cfwh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人
     */
    private String qlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原查封文号
     */
    private String ycfwh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原权利人
     */
    private String yqlr;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原权利人证件号
     */
    private String yqlrzjh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 原坐落
     */
    private String yzl;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 登簿时间
     */
    private Date dbsj;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/7/31
     * @description 不动产类型
     */
    private String bdclx;

    public String getCfid() {
        return cfid;
    }

    public void setCfid(String cfid) {
        this.cfid = cfid;
    }

    public String getYcfid() {
        return ycfid;
    }

    public void setYcfid(String ycfid) {
        this.ycfid = ycfid;
    }

    public String getCfwh() {
        return cfwh;
    }

    public void setCfwh(String cfwh) {
        this.cfwh = cfwh;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getYcfwh() {
        return ycfwh;
    }

    public void setYcfwh(String ycfwh) {
        this.ycfwh = ycfwh;
    }

    public String getYqlr() {
        return yqlr;
    }

    public void setYqlr(String yqlr) {
        this.yqlr = yqlr;
    }

    public String getYqlrzjh() {
        return yqlrzjh;
    }

    public void setYqlrzjh(String yqlrzjh) {
        this.yqlrzjh = yqlrzjh;
    }

    public String getYzl() {
        return yzl;
    }

    public void setYzl(String yzl) {
        this.yzl = yzl;
    }

    public Date getDbsj() {
        return dbsj;
    }

    public void setDbsj(Date dbsj) {
        this.dbsj = dbsj;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }
}
